// python wrapper for vtkPLagrangianParticleTracker
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include "vtkConfigure.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkPLagrangianParticleTracker.h"

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkPLagrangianParticleTracker(PyObject *); }
extern "C" { VTK_ABI_EXPORT PyObject *PyvtkPLagrangianParticleTracker_ClassNew(); }

#ifndef DECLARED_PyvtkLagrangianParticleTracker_ClassNew
extern "C" { PyObject *PyvtkLagrangianParticleTracker_ClassNew(); }
#define DECLARED_PyvtkLagrangianParticleTracker_ClassNew
#endif

static const char *PyvtkPLagrangianParticleTracker_Doc =
  "vtkPLagrangianParticleTracker - parallel Lagrangian particle tracker\n\n"
  "Superclass: vtkLagrangianParticleTracker\n\n"
  "This class implements parallel Lagrangian particle tracker. The\n"
  "implementation is as follows: First seeds input is parsed to create\n"
  "particle in each rank Particles which are not contained by the flow\n"
  "in a rank are sent to other ranks which can potentially contain it\n"
  "and will grab only if they actually contain it Then each rank begin\n"
  "integrating. When a particle goes out of domain, the particle will be\n"
  "sent to other ranks the same way. When a rank runs out of particle,\n"
  "it waits for other potentiel particles from other ranks. When all\n"
  "ranks run out of particles, integration is over. The master rank\n"
  "takes care of communications between rank regarding integration\n"
  "termination particles are directly streamed rank to rank, without\n"
  "going through the master\n\n"
  "@sa\n"
  "vtkStreamTracer\n\n";


static PyObject *
PyvtkPLagrangianParticleTracker_IsTypeOf(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkPLagrangianParticleTracker::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPLagrangianParticleTracker_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPLagrangianParticleTracker *op = static_cast<vtkPLagrangianParticleTracker *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkPLagrangianParticleTracker::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPLagrangianParticleTracker_SafeDownCast(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkPLagrangianParticleTracker *tempr = vtkPLagrangianParticleTracker::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPLagrangianParticleTracker_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPLagrangianParticleTracker *op = static_cast<vtkPLagrangianParticleTracker *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkPLagrangianParticleTracker *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkPLagrangianParticleTracker::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(0);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}

static PyMethodDef PyvtkPLagrangianParticleTracker_Methods[] = {
  {"IsTypeOf", PyvtkPLagrangianParticleTracker_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkPLagrangianParticleTracker_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkPLagrangianParticleTracker_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkPLagrangianParticleTracker\nC++: static vtkPLagrangianParticleTracker *SafeDownCast(\n    vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkPLagrangianParticleTracker_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkPLagrangianParticleTracker\nC++: vtkPLagrangianParticleTracker *NewInstance()\n\n"},
  {nullptr, nullptr, 0, nullptr}
};

static PyTypeObject PyvtkPLagrangianParticleTracker_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  "vtkFiltersParallelFlowPathsPython.vtkPLagrangianParticleTracker", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
  0, // tp_vectorcall_offset
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkPLagrangianParticleTracker_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkPLagrangianParticleTracker_StaticNew()
{
  return vtkPLagrangianParticleTracker::New();
}

PyObject *PyvtkPLagrangianParticleTracker_ClassNew()
{
  PyVTKClass_Add(
    &PyvtkPLagrangianParticleTracker_Type, PyvtkPLagrangianParticleTracker_Methods,
    "vtkPLagrangianParticleTracker",
 &PyvtkPLagrangianParticleTracker_StaticNew);

  PyTypeObject *pytype = &PyvtkPLagrangianParticleTracker_Type;

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#if !defined(VTK_PY3K) && PY_VERSION_HEX >= 0x02060000
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = (PyTypeObject *)PyvtkLagrangianParticleTracker_ClassNew();

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkPLagrangianParticleTracker(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkPLagrangianParticleTracker_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkPLagrangianParticleTracker", o) != 0)
  {
    Py_DECREF(o);
  }

}

