/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkFiltersParallelGeometryObjectFactory.cxx

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/

#include "vtkFiltersParallelGeometryObjectFactory.h"
#include "vtkVersion.h"

// Include all of the classes we want to create overrides for.

#include "vtkPUnstructuredGridGhostCellsGenerator.h"
#include "vtkPConnectivityFilter.h"

vtkStandardNewMacro(vtkFiltersParallelGeometryObjectFactory)

// Now create the functions to create overrides with.

  VTK_CREATE_CREATE_FUNCTION(vtkPUnstructuredGridGhostCellsGenerator)
  VTK_CREATE_CREATE_FUNCTION(vtkPConnectivityFilter)

vtkFiltersParallelGeometryObjectFactory::vtkFiltersParallelGeometryObjectFactory()
{

    this->RegisterOverride("vtkUnstructuredGridGhostCellsGenerator",
                           "vtkPUnstructuredGridGhostCellsGenerator",
                           "Override for vtkFiltersParallelGeometry module", 1,
                           vtkObjectFactoryCreatevtkPUnstructuredGridGhostCellsGenerator);
    this->RegisterOverride("vtkConnectivityFilter",
                           "vtkPConnectivityFilter",
                           "Override for vtkFiltersParallelGeometry module", 1,
                           vtkObjectFactoryCreatevtkPConnectivityFilter);
}

const char * vtkFiltersParallelGeometryObjectFactory::GetVTKSourceVersion()
{
  return VTK_SOURCE_VERSION;
}

void vtkFiltersParallelGeometryObjectFactory::PrintSelf(ostream &os, vtkIndent indent)
{
  this->Superclass::PrintSelf(os, indent);
}

// Registration of object factories.
static unsigned int vtkFiltersParallelGeometryCount;

VTKFILTERSPARALLELGEOMETRY_EXPORT void vtkFiltersParallelGeometry_AutoInit_Construct()
{
  if(++vtkFiltersParallelGeometryCount == 1)
    {
    
    vtkFiltersParallelGeometryObjectFactory* factory = vtkFiltersParallelGeometryObjectFactory::New();
    if (factory)
      {
      // vtkObjectFactory keeps a reference to the "factory",
      vtkObjectFactory::RegisterFactory(factory);
      factory->Delete();
      }
    }
}

VTKFILTERSPARALLELGEOMETRY_EXPORT void vtkFiltersParallelGeometry_AutoInit_Destruct()
{
  if(--vtkFiltersParallelGeometryCount == 0)
    {
    // Do not call vtkObjectFactory::UnRegisterFactory because
    // vtkObjectFactory.cxx statically unregisters all factories.
    }
}
